==> com.liferay.frontend.editor.tinymce.web-3.0.9.jar: META-INF/resources/_diffs/langs/eu.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('eu', {
	Cut: 'Ebaki',
	'Heading 5': '5. izenburua',
	'Header 2': '2 Goiburua',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Zure nabigatzaileak ez du arbela zuzenean erabiltzeko euskarririk. Mesedez erabili CTRL+X/C/V teklatuko lasterbideak.',
	'Heading 4': '4. izenburua',
	Div: 'Div',
	'Heading 2': '2. izenburua',
	Paste: 'Itsatsi',
	Close: 'Itxi',
	'Font Family': 'Letra-tipo familia',
	Pre: 'Pre',
	'Align right': 'Lerrokatu eskuinean',
	'New document': 'Dokumentu berria',
	Blockquote: 'Blockquote',
	'Numbered list': 'Zerrenda  zenbatua',
	'Heading 1': '1. izenburua',
	Headings: 'Izenburuak',
	'Increase indent': 'Handitu koska',
	Formats: 'Formatuak',
	Headers: 'Goiburuak',
	'Select all': 'Hautatu dena',
	'Header 3': '3 Goiburua',
	Blocks: 'Blokeak',
	Undo: 'Desegin',
	Strikethrough: 'Marratua',
	'Bullet list': 'Bulet zerrenda',
	'Header 1': '1 Goiburua',
	Superscript: 'Goi-indize',
	'Clear formatting': 'Garbitu formatua',
	'Font Sizes': 'Letra-tamainuak',
	Subscript: 'Azpiindize',
	'Header 6': '6 Goiburua',
	Redo: 'Berregin',
	Paragraph: 'Parrafoa',
	Ok: 'Ondo',
	Bold: 'Lodia',
	Code: 'Kodea',
	Italic: 'Etzana',
	'Align center': 'Lerrokatu horizontalki erdian',
	'Header 5': '5 Goiburua',
	'Heading 6': '6. izenburua',
	'Heading 3': '3. izenburua',
	'Decrease indent': 'Txikitu koska',
	'Header 4': '4 Goiburua',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Itsatsi testu arrunt moduan dago orain. Edukiak testu arruntak bezala itsatsiko dira aukera hau itzaltzen duzunera arte.',
	Underline: 'Azpimarratua',
	Cancel: 'Ezeztatu',
	Justify: 'Justifikatuta',
	Inline: 'Lerroan',
	Copy: 'Kopiatu',
	'Align left': 'Lerrokatu ezkerrean',
	'Visual aids': 'Laguntza bisualak',
	'Lower Greek': 'Behe grekoa',
	Square: 'Karratua',
	Default: 'Lehenetstia',
	'Lower Alpha': 'Behe alfa',
	Circle: 'Zirkulua',
	Disc: 'Diskoa',
	'Upper Alpha': 'Goi alfa',
	'Upper Roman': 'Goi erromatarra',
	'Lower Roman': 'Behe erromatarra',
	Name: 'Izena',
	Anchor: 'Esteka',
	'You have unsaved changes are you sure you want to navigate away?':
		'Gorde gabeko aldaketak dituzu, zihur zaude hemendik irten nahi duzula?',
	'Restore last draft': 'Leheneratu azken zirriborroa',
	'Special character': 'Karaktere bereziak',
	'Source code': 'Iturburu-kodea',
	'Right to left': 'Eskuinetik ezkerrera',
	'Left to right': 'Ezkerretik eskuinera',
	Emoticons: 'Irrifartxoak',
	Robots: 'Robotak',
	'Document properties': 'Dokumentuaren propietateak',
	Title: 'Titulua',
	Keywords: 'Hitz gakoak',
	Encoding: 'Encoding',
	Description: 'Deskribapena',
	Author: 'Egilea',
	Fullscreen: 'Pantaila osoa',
	'Horizontal line': 'Marra horizontala',
	'Horizontal space': 'Hutsune horizontala',
	'Insert/edit image': 'Irudia txertatu/editatu',
	General: 'Orokorra',
	Advanced: 'Aurreratua',
	Source: 'Iturburua',
	Border: 'Ertza',
	'Constrain proportions': 'Zerraditu proportzioak',
	'Vertical space': 'Hutsune bertikala',
	'Image description': 'Irudiaren deskribapena',
	Style: 'Estiloa',
	Dimensions: 'Neurriak',
	'Insert image': 'Irudia txertatu',
	'Insert date/time': 'Data/ordua txertatu',
	'Remove link': 'Kendu esteka',
	Url: 'Url',
	'Text to display': 'Bistaratzeko testua',
	Anchors: 'Estekak',
	'Insert link': 'Esteka txertatu',
	'New window': 'Lehio berria',
	None: 'Bat ere ez',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Sartu duzun URL-ak kanpoko esteka dela dirudi. Nahi duzu dagokion http:// aurrizkia gehitzea?',
	Target: 'Target',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Sartu duzun URL-ak e-posta helbidea dela dirudi. Nahi duzu dagokion mailto: aurrizkia gehitzea?',
	'Insert/edit link': 'Esteka txertatu/editatu',
	'Insert/edit video': 'Bideoa txertatu/editatu',
	Poster: 'Poster-a',
	'Alternative source': 'Iturburu alternatiboa',
	'Paste your embed code below:': 'Itsatsi hemen zure enkapsulatzeko kodea:',
	'Insert video': 'Bideoa txertatu',
	Embed: 'Kapsulatu',
	'Nonbreaking space': 'Zuriune zatiezina',
	'Page break': 'Orrialde-jauzia',
	'Paste as text': 'Itsatsi testu bezala',
	Preview: 'Aurrebista',
	Print: 'Inprimatu',
	Save: 'Gorde',
	'Could not find the specified string.':
		'Ezin izan da zehaztutako katea aurkitu.',
	Replace: 'Ordeztu',
	Next: 'Hurrengoa',
	'Whole words': 'hitz osoak',
	'Find and replace': 'Bilatu eta ordeztu',
	'Replace with': 'Honekin ordeztu',
	Find: 'Bilatu',
	'Replace all': 'Ordeztu dena',
	'Match case': 'Maiuskula/minuskula',
	Prev: 'Aurrekoa',
	Spellcheck: 'Egiaztapenak',
	Finish: 'Amaitu',
	'Ignore all': 'Ez ikusi guztia',
	Ignore: 'Ez ikusi',
	'Add to Dictionary': 'Gehitu hiztegira',
	'Insert row before': 'Txertatu errenkada aurretik',
	Rows: 'Errenkadak',
	Height: 'Altuera',
	'Paste row after': 'Itsatsi errenkada ostean',
	Alignment: 'Lerrokatzea',
	'Border color': 'Bordearen kolorea',
	'Column group': 'Zutabe taldea',
	Row: 'Errenkada',
	'Insert column before': 'Txertatu zutabe aurretik',
	'Split cell': 'Banatu gelaxkak',
	'Cell padding': 'Gelaxken betegarria',
	'Cell spacing': 'Gelaxka arteko tartea',
	'Row type': 'Lerro mota',
	'Insert table': 'Txertatu taula',
	Body: 'Gorputza',
	Caption: 'Epigrafea',
	Footer: 'Oina',
	'Delete row': 'Ezabatu errenkada',
	'Paste row before': 'Itsatsi errenkada aurretik',
	Scope: 'Esparrua',
	'Delete table': 'Taula ezabatu',
	'H Align': 'Lerrokatze horizontala',
	Top: 'Goian',
	'Header cell': 'Goiburuko gelaxka',
	Column: 'Zutabea',
	'Row group': 'Lerro taldea',
	Cell: 'Gelaxka',
	Middle: 'Erdian',
	'Cell type': 'Gelaxka mota',
	'Copy row': 'Kopiatu errenkada',
	'Row properties': 'Errenkadaren propietateak',
	'Table properties': 'Taularen propietateak',
	Bottom: 'Behean',
	'V Align': 'Lerrokatze bertikala',
	Header: 'Goiburua',
	Right: 'Eskuina',
	'Insert column after': 'Txertatu zutabea ostean',
	Cols: 'Zutabeak',
	'Insert row after': 'Txertatu errenkada ostean',
	Width: 'Zabalera',
	'Cell properties': 'Gelaxkaren propietateak',
	Left: 'Ezkerra',
	'Cut row': 'Ebaki errenkada',
	'Delete column': 'Ezabatu zutabea',
	Center: 'Erdia',
	'Merge cells': 'Batu gelaxkak',
	'Insert template': 'Txertatu txantiloia',
	Templates: 'Txantiloiak',
	'Background color': 'Atzeko kolorea',
	'Custom...': 'Pertsonalizatua...',
	'Custom color': 'Kolore pertsonalizatua',
	'No color': 'Kolorerik gabe',
	'Text color': 'Testuaren kolorea',
	'Show blocks': 'Erakutsi blokeak',
	'Show invisible characters': 'Erakutsi karaktere izkutuak',
	'Words: {0}': 'Hitzak: {0}',
	Insert: 'Sartu',
	File: 'Fitxategia',
	Edit: 'Editatu',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Testu aberastuko area. Sakatu ALT-F9 menurako. Sakatu ALT-F10 tresna-barrarako. Sakatu ALT-0 laguntzarako',
	Tools: 'Tresnak',
	View: 'Ikusi',
	Table: 'Taula',
	Format: 'Formatua'
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/eu.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('eu', {
	'Cut': 'Ebaki',
	'Heading 5': '5. izenburua',
	'Header 2': '2 Goiburua',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Zure nabigatzaileak ez du arbela zuzenean erabiltzeko euskarririk. Mesedez erabili CTRL+X/C/V teklatuko lasterbideak.',
	'Heading 4': '4. izenburua',
	'Div': 'Div',
	'Heading 2': '2. izenburua',
	'Paste': 'Itsatsi',
	'Close': 'Itxi',
	'Font Family': 'Letra-tipo familia',
	'Pre': 'Pre',
	'Align right': 'Lerrokatu eskuinean',
	'New document': 'Dokumentu berria',
	'Blockquote': 'Blockquote',
	'Numbered list': 'Zerrenda  zenbatua',
	'Heading 1': '1. izenburua',
	'Headings': 'Izenburuak',
	'Increase indent': 'Handitu koska',
	'Formats': 'Formatuak',
	'Headers': 'Goiburuak',
	'Select all': 'Hautatu dena',
	'Header 3': '3 Goiburua',
	'Blocks': 'Blokeak',
	'Undo': 'Desegin',
	'Strikethrough': 'Marratua',
	'Bullet list': 'Bulet zerrenda',
	'Header 1': '1 Goiburua',
	'Superscript': 'Goi-indize',
	'Clear formatting': 'Garbitu formatua',
	'Font Sizes': 'Letra-tamainuak',
	'Subscript': 'Azpiindize',
	'Header 6': '6 Goiburua',
	'Redo': 'Berregin',
	'Paragraph': 'Parrafoa',
	'Ok': 'Ondo',
	'Bold': 'Lodia',
	'Code': 'Kodea',
	'Italic': 'Etzana',
	'Align center': 'Lerrokatu horizontalki erdian',
	'Header 5': '5 Goiburua',
	'Heading 6': '6. izenburua',
	'Heading 3': '3. izenburua',
	'Decrease indent': 'Txikitu koska',
	'Header 4': '4 Goiburua',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Itsatsi testu arrunt moduan dago orain. Edukiak testu arruntak bezala itsatsiko dira aukera hau itzaltzen duzunera arte.',
	'Underline': 'Azpimarratua',
	'Cancel': 'Ezeztatu',
	'Justify': 'Justifikatuta',
	'Inline': 'Lerroan',
	'Copy': 'Kopiatu',
	'Align left': 'Lerrokatu ezkerrean',
	'Visual aids': 'Laguntza bisualak',
	'Lower Greek': 'Behe grekoa',
	'Square': 'Karratua',
	'Default': 'Lehenetstia',
	'Lower Alpha': 'Behe alfa',
	'Circle': 'Zirkulua',
	'Disc': 'Diskoa',
	'Upper Alpha': 'Goi alfa',
	'Upper Roman': 'Goi erromatarra',
	'Lower Roman': 'Behe erromatarra',
	'Name': 'Izena',
	'Anchor': 'Esteka',
	'You have unsaved changes are you sure you want to navigate away?':
		'Gorde gabeko aldaketak dituzu, zihur zaude hemendik irten nahi duzula?',
	'Restore last draft': 'Leheneratu azken zirriborroa',
	'Special character': 'Karaktere bereziak',
	'Source code': 'Iturburu-kodea',
	'Right to left': 'Eskuinetik ezkerrera',
	'Left to right': 'Ezkerretik eskuinera',
	'Emoticons': 'Irrifartxoak',
	'Robots': 'Robotak',
	'Document properties': 'Dokumentuaren propietateak',
	'Title': 'Titulua',
	'Keywords': 'Hitz gakoak',
	'Encoding': 'Encoding',
	'Description': 'Deskribapena',
	'Author': 'Egilea',
	'Fullscreen': 'Pantaila osoa',
	'Horizontal line': 'Marra horizontala',
	'Horizontal space': 'Hutsune horizontala',
	'Insert/edit image': 'Irudia txertatu/editatu',
	'General': 'Orokorra',
	'Advanced': 'Aurreratua',
	'Source': 'Iturburua',
	'Border': 'Ertza',
	'Constrain proportions': 'Zerraditu proportzioak',
	'Vertical space': 'Hutsune bertikala',
	'Image description': 'Irudiaren deskribapena',
	'Style': 'Estiloa',
	'Dimensions': 'Neurriak',
	'Insert image': 'Irudia txertatu',
	'Insert date/time': 'Data/ordua txertatu',
	'Remove link': 'Kendu esteka',
	'Url': 'Url',
	'Text to display': 'Bistaratzeko testua',
	'Anchors': 'Estekak',
	'Insert link': 'Esteka txertatu',
	'New window': 'Lehio berria',
	'None': 'Bat ere ez',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'Sartu duzun URL-ak kanpoko esteka dela dirudi. Nahi duzu dagokion http:// aurrizkia gehitzea?',
	'Target': 'Target',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'Sartu duzun URL-ak e-posta helbidea dela dirudi. Nahi duzu dagokion mailto: aurrizkia gehitzea?',
	'Insert/edit link': 'Esteka txertatu/editatu',
	'Insert/edit video': 'Bideoa txertatu/editatu',
	'Poster': 'Poster-a',
	'Alternative source': 'Iturburu alternatiboa',
	'Paste your embed code below:': 'Itsatsi hemen zure enkapsulatzeko kodea:',
	'Insert video': 'Bideoa txertatu',
	'Embed': 'Kapsulatu',
	'Nonbreaking space': 'Zuriune zatiezina',
	'Page break': 'Orrialde-jauzia',
	'Paste as text': 'Itsatsi testu bezala',
	'Preview': 'Aurrebista',
	'Print': 'Inprimatu',
	'Save': 'Gorde',
	'Could not find the specified string.':
		'Ezin izan da zehaztutako katea aurkitu.',
	'Replace': 'Ordeztu',
	'Next': 'Hurrengoa',
	'Whole words': 'hitz osoak',
	'Find and replace': 'Bilatu eta ordeztu',
	'Replace with': 'Honekin ordeztu',
	'Find': 'Bilatu',
	'Replace all': 'Ordeztu dena',
	'Match case': 'Maiuskula/minuskula',
	'Prev': 'Aurrekoa',
	'Spellcheck': 'Egiaztapenak',
	'Finish': 'Amaitu',
	'Ignore all': 'Ez ikusi guztia',
	'Ignore': 'Ez ikusi',
	'Add to Dictionary': 'Gehitu hiztegira',
	'Insert row before': 'Txertatu errenkada aurretik',
	'Rows': 'Errenkadak',
	'Height': 'Altuera',
	'Paste row after': 'Itsatsi errenkada ostean',
	'Alignment': 'Lerrokatzea',
	'Border color': 'Bordearen kolorea',
	'Column group': 'Zutabe taldea',
	'Row': 'Errenkada',
	'Insert column before': 'Txertatu zutabe aurretik',
	'Split cell': 'Banatu gelaxkak',
	'Cell padding': 'Gelaxken betegarria',
	'Cell spacing': 'Gelaxka arteko tartea',
	'Row type': 'Lerro mota',
	'Insert table': 'Txertatu taula',
	'Body': 'Gorputza',
	'Caption': 'Epigrafea',
	'Footer': 'Oina',
	'Delete row': 'Ezabatu errenkada',
	'Paste row before': 'Itsatsi errenkada aurretik',
	'Scope': 'Esparrua',
	'Delete table': 'Taula ezabatu',
	'H Align': 'Lerrokatze horizontala',
	'Top': 'Goian',
	'Header cell': 'Goiburuko gelaxka',
	'Column': 'Zutabea',
	'Row group': 'Lerro taldea',
	'Cell': 'Gelaxka',
	'Middle': 'Erdian',
	'Cell type': 'Gelaxka mota',
	'Copy row': 'Kopiatu errenkada',
	'Row properties': 'Errenkadaren propietateak',
	'Table properties': 'Taularen propietateak',
	'Bottom': 'Behean',
	'V Align': 'Lerrokatze bertikala',
	'Header': 'Goiburua',
	'Right': 'Eskuina',
	'Insert column after': 'Txertatu zutabea ostean',
	'Cols': 'Zutabeak',
	'Insert row after': 'Txertatu errenkada ostean',
	'Width': 'Zabalera',
	'Cell properties': 'Gelaxkaren propietateak',
	'Left': 'Ezkerra',
	'Cut row': 'Ebaki errenkada',
	'Delete column': 'Ezabatu zutabea',
	'Center': 'Erdia',
	'Merge cells': 'Batu gelaxkak',
	'Insert template': 'Txertatu txantiloia',
	'Templates': 'Txantiloiak',
	'Background color': 'Atzeko kolorea',
	'Custom...': 'Pertsonalizatua...',
	'Custom color': 'Kolore pertsonalizatua',
	'No color': 'Kolorerik gabe',
	'Text color': 'Testuaren kolorea',
	'Show blocks': 'Erakutsi blokeak',
	'Show invisible characters': 'Erakutsi karaktere izkutuak',
	'Words: {0}': 'Hitzak: {0}',
	'Insert': 'Sartu',
	'File': 'Fitxategia',
	'Edit': 'Editatu',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Testu aberastuko area. Sakatu ALT-F9 menurako. Sakatu ALT-F10 tresna-barrarako. Sakatu ALT-0 laguntzarako',
	'Tools': 'Tresnak',
	'View': 'Ikusi',
	'Table': 'Taula',
	'Format': 'Formatua',
});
